========
polysign
========


.. image:: https://img.shields.io/pypi/v/polysign.svg
        :target: https://pypi.python.org/pypi/polysign

.. image:: https://img.shields.io/travis/EggPool/polysign.svg
        :target: https://travis-ci.org/EggPool/polysign

.. image:: https://readthedocs.org/projects/polysign/badge/?version=latest
        :target: https://polysign.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Polysign PIP module for Bismuth. Handles the various cryptographic primitives Bismuth Crypto currency supports.


* Free software: MIT license
* Documentation: https://polysign.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
